@@ -6,12 +6,17 @@
 #' or condition with a message that matches `regexp`, or a class that inherits
 #' from `class`. See below for more details.
 #'
-#' New in the 3rd edition, if the code throws conditions that don't match
-#' `regexp`/`class` they will bubble up outside of the expectation, so if
-#' they're important you'll need to catch them with additional
-#' `expect_message()`/`expect_warning()` calls, or if they're unimportant you
+#' In the 3rd edition, these functions match a single condition. All
+#' additional and non-matching (if `regexp` or `class` are used) conditions
+#' will bubble up outside the expectation. If these additional conditions
+#' are important you'll need to catch them with additional
+#' `expect_message()`/`expect_warning()` calls; if they're unimportant you
 #' can ignore with [suppressMessages()]/[suppressWarnings()].
 #'
+#' It can be tricky to test for a combination of different conditions,
+#' such as a message followed by an error. [expect_snapshot()] is
+#' often an easier alternative for these more complex cases.
+#'
 #' @section Testing `message` vs `class`:
 #' When checking that code generates an error, it's important to check that the
 #' error is the one you expect. There are two ways to do this. The first
@@ -328,7 +333,7 @@ compare_condition_2e <- function(cond, lab, regexp = NULL, class = NULL, ...,
   message <- cnd_message(cond)
 
   ok_class <- is.null(class) || inherits(cond, class)
-  ok_msg <- is.null(regexp) || grepl(regexp, message, ...)
+  ok_msg <- is.null(regexp) || any(grepl(regexp, message, ...))
 
   # All good
   if (ok_msg && ok_class) {
@@ -407,6 +412,6 @@ compare_messages <- function(messages,
 # Disable rlang backtrace reminders so they don't interfere with
 # expected error messages
 cnd_message <- function(x) {
-  withr::local_options(c(rlang_backtrace_on_error = "none"))
+  withr::local_options(rlang_backtrace_on_error = "none")
   conditionMessage(x)
 }
