@@ -1,6 +1,3 @@
-context("evaluate promise")
-
-
 test_that("captures warnings, messages and output", {
   out <- evaluate_promise({
     message("m", appendLF = FALSE)
@@ -14,12 +11,18 @@ test_that("captures warnings, messages and output", {
 })
 
 test_that("capture_warnings captures warnings", {
-  out <- capture_warnings({warning("a"); warning("b")})
+  out <- capture_warnings({
+    warning("a")
+    warning("b")
+  })
   expect_equal(out, c("a", "b"))
 })
 
 test_that("capture_messages captures messages", {
-  out <- capture_messages({message("a"); message("b")})
+  out <- capture_messages({
+    message("a")
+    message("b")
+  })
   expect_equal(out, c("a\n", "b\n")) # message adds LF by default
 })
 
