@@ -12,7 +12,7 @@ test_that("basic workflow", {
   snapper <- local_snapshotter(tempfile(), cleanup = TRUE)
   snapper$start_file("snapshot-2")
   # output if not active (because test not set here)
-  expect_output(expect_snapshot_output("x"), "No snapshotter active")
+  expect_message(expect_snapshot_output("x"), "Can't compare")
 
   # warns on first creation
   snapper$start_file("snapshot-2", "test")
@@ -82,3 +82,25 @@ test_that("errors in test doesn't change snapshot", {
   )
   snapper$end_file()
 })
+
+test_that("skips and unexpected errors reset snapshots", {
+  regenerate <- FALSE
+
+  if (regenerate) {
+    withr::local_envvar(c(TESTTHAT_REGENERATE_SNAPS = "true"))
+  }
+
+  catch_cnd(
+    test_file(
+      test_path("test-snapshot", "test-snapshot.R"),
+      reporter = NULL
+    )
+  )
+
+  path <- "test-snapshot/_snaps/snapshot.md"
+  stopifnot(file.exists(path))
+
+  snaps <- snap_from_md(read_lines(path))
+  titles <- c("errors reset snapshots", "skips reset snapshots")
+  expect_true(all(titles %in% names(snaps)))
+})
